@@ -46,6 +46,8 @@ from .geo2rdb import geojson2rethinkjson
 from rethinkdb import RethinkDB
 rdb = RethinkDB()
 rdb.set_loop_type('asyncio')
+from networktools.path import home_path
+from basic_logtools.filelog import LogFile
 
 
 def qjson(x): return json.loads(json.dumps(x))
@@ -56,7 +58,7 @@ class DragonGather(TaskScheduler):
 
     def __init__(self, queue_list, *args, **kwargs):
         # super().__init__()
-        self.log_path = Path(kwargs.get('log_path', '~/log'))
+
         self.key = 'DT_GEN'
         self.ipt = kwargs.get('ipt')
         self.ico = kwargs.get('ico')
@@ -116,6 +118,13 @@ class DragonGather(TaskScheduler):
             'run_task': self.gather_data,
         }
         self.set_new_run_task(**coros_callback_dict)
+        self.log_path = home_path(kwargs.get('log_path', '~/log'))
+        log_level = kwargs.get('log_level', 'INFO')
+
+    @property
+    def class_name(self):
+        return self.__class__.__name__
+
 
     def set_isg(self, uin=4):
         """
@@ -569,6 +578,11 @@ class DragonGather(TaskScheduler):
         The logging system is a task by process
         """
         # input : ids, loop, sta
+        uin = 3
+        idi=my_random_string(uin)
+        print("====Datawork Gather Iteration===")
+        bprint("idi %s, args %s"%(idi,args))
+        rprint("idi %s, kwargs %s" %(idi, kwargs))
         await asyncio.sleep(.5)
         loop = asyncio.get_event_loop()
         log = kwargs.get('log')
@@ -613,9 +627,10 @@ class DragonGather(TaskScheduler):
                 await rc.list_tables(rc.default_db)
                 origin = True
             except asyncio.TimeoutError as e:
+                idex=my_random_string(uin)
                 log.exception(
-                    "PD_TO1: Tiempo fuera para conectar db source %s" % rc)
-                kwargs["origin_exception"] = "PD_TO1_00 + %s" % code
+                    "PD_TO1 IDEX %s: Tiempo fuera para conectar db source %s" % rc)
+                kwargs["origin_exception"] = "PD_TO1_00 + %s" % (idex, code)
                 self.rethinkdb_origin[ids] = False
                 rc.close()
                 del rc
@@ -644,8 +659,9 @@ class DragonGather(TaskScheduler):
                 await rc_enu.list_tables(rc_enu.default_db)
                 destiny = True
             except asyncio.TimeoutError as e:
+                idex=my_random_string(uin)
                 log.exception(
-                    "PD_TO2: Tiempo fuera para conectar db destiny %s" % rc)
+                    "PD_TO2 IDEX %s: Tiempo fuera para conectar db destiny %s" % (idex, rc))
                 kwargs["origin_exception"] = "PD_TO1_00 + %s" % code
                 self.rethinkdb_origin_enu[ids] = False
                 bprint(kwargs)
@@ -672,22 +688,27 @@ class DragonGather(TaskScheduler):
                                             key)
                 cursor = await shield(wait_for(future, timeout=30))
             except asyncio.TimeoutError as e:
+                idex=my_random_string(uin)
                 log.exception(
-                    "PD_TO3: Tiempo fuera para conectar db % s, al leer datos desde db" % rc)
+                    "PD_TO3 IDEX %s: Tiempo fuera para conectar db % s, al leer datos desde db, tabla %s" % (
+                        idex, rc, table_name))
                 kwargs["origin_exception"] = "PD_TO3_00 + %s" % code
                 self.rethinkdb_origin[ids] = False
                 bprint(kwargs)
                 rc.close()
                 del rc
                 rc=None
+                log.exception("PD_TO3 IDEX %s: next iteration" % (idex, table_name))
                 wargs = [ipt, ids, v, [
                     di, control, (rc, rc_enu), process_data]]
                 return wargs, kwargs
             except Exception as ex:
-                print("Exception", ex)
+                idex=my_random_string(uin)
+                print("IDEX %s Exception" % idex, ex)
                 print("Error en obtención de data desde rethinkdb")
                 rc.logerror(
-                    "Error en la obtención de datos para estación %s en %s" % (code, di))
+                    "IDEX = %s, Error en la obtención de datos para estación %s en %s" % (
+                        idex,code, di))
                 kwargs["origin_exception"] = "PD_TO4_00 + %s" % code
                 self.rethinkdb_origin[ids] = False
                 rc.close()
